package com.ruoyi.web.controller.system;

import java.util.*;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.system.domain.SysRepo;
import com.ruoyi.system.service.impl.SysDictTypeServiceImpl;
import com.ruoyi.system.service.impl.SysRepoServiceImpl;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysCompanyTemplate;
import com.ruoyi.system.service.ISysCompanyTemplateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 企业模板配置Controller
 *
 * @author lixu
 * @date 2025-05-21
 */
@RestController
@RequestMapping("/system/template")
public class SysCompanyTemplateController extends BaseController
{
    @Autowired
    private ISysCompanyTemplateService sysCompanyTemplateService;
    @Autowired
    private SysDictTypeServiceImpl sysDictTypeServiceImpl;
    @Autowired
    private SysRepoServiceImpl sysRepoServiceImpl;

    /**
     * 查询企业模板列表
     */
    @PreAuthorize("@ss.hasPermi('system:template:list')")
    @GetMapping("/list")
    public AjaxResult list(SysCompanyTemplate sysCompanyTemplate)
    {
        startPage();
        List<SysCompanyTemplate> list = sysCompanyTemplateService.selectSysCompanyTemplateList(sysCompanyTemplate);
        return AjaxResult.success(getDataTable(list));
    }


    /**
     * 获取模板详情列表
     */
    @PreAuthorize("@ss.hasPermi('system:template:getTemplate')")
    @Log(title = "获取模板详情列表", businessType = BusinessType.EXPORT)
    @GetMapping("/getTemplate")
    public AjaxResult getTemplate()
    {
        Map map = new HashMap<>();
        SysRepo sysRepo = new SysRepo();
        List<SysDictData> list = sysDictTypeServiceImpl.selectDictDataByType("sys_repo_group");
        if(list == null){
            return AjaxResult.warn("未找到该类型");
        }else{
            for(SysDictData sysDictData:list){
                sysRepo.setGroupId(sysDictData.getDictValue());
                map.put(sysDictData.getDictLabel(),sysRepoServiceImpl.selectSysRepoList(sysRepo));
            }
            return AjaxResult.success(map);
        }
    }

    /**
     * 获取企业模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:template:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        SysCompanyTemplate sysCompanyTemplate = sysCompanyTemplateService.selectSysCompanyTemplateById(id);
        if(sysCompanyTemplate.getTemplate() != null && !"".equals(sysCompanyTemplate.getTemplate())){
//            String template = sysCompanyTemplate.getTemplate().substring(1, sysCompanyTemplate.getTemplate().length()-1);
            String[] templateList = sysCompanyTemplate.getTemplate().split(",");
            Long[] templateIds = new Long[templateList.length];
            for(int i = 0;i<templateList.length;i++){
                templateIds[i] = Long.parseLong(templateList[i]);
            }
            sysCompanyTemplate.setTemplateIds(new ArrayList<>(Arrays.asList(templateIds)));
            sysCompanyTemplate.setTemplateList(sysRepoServiceImpl.selectSysRepoListByRepoIds(templateIds));
        }
        return success(sysCompanyTemplate);
    }

    /**
     * 新增企业模板
     */
    @PreAuthorize("@ss.hasPermi('system:template:add')")
    @Log(title = "新增企业模板信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysCompanyTemplate sysCompanyTemplate)
    {
        sysCompanyTemplate.setUpdateBy(getUsername());
        return toAjax(sysCompanyTemplateService.insertSysCompanyTemplate(sysCompanyTemplate));
    }

    /**
     * 修改企业模板接口
     */
    @PreAuthorize("@ss.hasPermi('system:template:edit')")
    @Log(title = "修改企业模板信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysCompanyTemplate sysCompanyTemplate)
    {
        sysCompanyTemplate.setUpdateBy(getUsername());
        sysCompanyTemplate.setTemplate(sysCompanyTemplate.getTemplateIds().stream().map(String::valueOf).collect(Collectors.joining(",")));
        return toAjax(sysCompanyTemplateService.updateSysCompanyTemplate(sysCompanyTemplate));
    }

    /**
     * 删除企业模板
     */
    @PreAuthorize("@ss.hasPermi('system:template:remove')")
    @Log(title = "删除企业模板信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysCompanyTemplateService.deleteSysCompanyTemplateByIds(ids));
    }
}
