package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysRepo;
import com.ruoyi.system.domain.SysRepoHistory;
import org.springframework.transaction.annotation.Transactional;

/**
 * 仓库文件Service接口
 * 
 * @author lixu
 * @date 2025-05-15
 */
public interface ISysRepoService 
{
    /**
     * 查询文化仓库
     * 
     * @param repoId 文件仓库主键
     * @return 文件仓库
     */
    public SysRepo selectSysRepoByRepoId(Long repoId);


    /**
     * 通过主键列表查询文件仓库信息列表
     *
     * @param repoIds 需要查询的文件仓库主键集合
     * @return 结果
     */

    public List<SysRepo> selectSysRepoListByRepoIds(Long[] repoIds);
    /**
     * 查询文件仓库列表
     * 
     * @param sysRepo 文件仓库
     * @return 文件仓库
     */
    public List<SysRepo> selectSysRepoList(SysRepo sysRepo);

    /**
     * 新增文件仓库
     * 
     * @param sysRepo 文件仓库
     * @return 结果
     */
    public int insertSysRepo(SysRepo sysRepo);

    /**
     * 修改文件仓库
     * 
     * @param sysRepo 文件仓库
     * @return 结果
     */
    public int updateSysRepo(SysRepo sysRepo);

    /**
     * 批量删除文件仓库
     * 
     * @param repoIds 需要删除的文件仓库主键集合
     * @return 结果
     */
    public int deleteSysRepoByRepoIds(Long[] repoIds);

    /**
     * 删除文件仓库信息
     * 
     * @param repoId 文件仓库主键
     * @return 结果
     */
    public int deleteSysRepoByRepoId(Long repoId);


    /**
     * 填充Sysrepo对象
     *
     * @param sysRepo 模板部分信息
     * @return 字段填充后的对象
     */
    public SysRepo createSysRepo(SysRepo sysRepo);

    /**
     * 插入仓库文件信息
     *
     * @param sysRepo 仓库文件信息
     * @param sysRepoHistory 仓库文件历史信息
     * @return 插入结果
     */
    public int insertSysRepoAndSysRepoHistory(SysRepo sysRepo, SysRepoHistory sysRepoHistory);
}
