package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.system.domain.SysRepo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SysRepoHistoryMapper;
import com.ruoyi.system.domain.SysRepoHistory;
import com.ruoyi.system.service.ISysRepoHistoryService;

/**
 * 文件历史业务层处理
 * 
 * @author lixu
 * @date 2025-05-19
 */
@Service
public class SysRepoHistoryServiceImpl implements ISysRepoHistoryService 
{
    @Autowired
    private SysRepoHistoryMapper sysRepoHistoryMapper;

    /**
     * 查询仓库历史版本
     * 
     * @param hId 仓库历史版本主键
     * @return 仓库历史版本
     */
    @Override
    public SysRepoHistory selectSysRepoHistoryByHId(Long hId)
    {
        return sysRepoHistoryMapper.selectSysRepoHistoryByHId(hId);
    }

    /**
     * 查询仓库历史版本列表
     * 
     * @param sysRepoHistory 仓库历史版本
     * @return 仓库历史版本
     */
    @Override
    public List<SysRepoHistory> selectSysRepoHistoryList(SysRepoHistory sysRepoHistory)
    {
        return sysRepoHistoryMapper.selectSysRepoHistoryList(sysRepoHistory);
    }

    /**
     * 查询仓库历史版本
     *
     * @param sysRepoHistory 仓库历史版本
     * @return 仓库历史版本
     */
    @Override
    public SysRepoHistory selectSysRepoHistory(SysRepoHistory sysRepoHistory)
    {
        return sysRepoHistoryMapper.selectSysRepoHistory(sysRepoHistory);
    }

    /**
     * 新增仓库历史版本
     * 
     * @param sysRepoHistory 仓库历史版本
     * @return 结果
     */
    @Override
    public int insertSysRepoHistory(SysRepoHistory sysRepoHistory)
    {
        return sysRepoHistoryMapper.insertSysRepoHistory(sysRepoHistory);
    }

    /**
     * 修改仓库历史版本
     * 
     * @param sysRepoHistory 仓库历史版本
     * @return 结果
     */
    @Override
    public int updateSysRepoHistory(SysRepoHistory sysRepoHistory)
    {
        return sysRepoHistoryMapper.updateSysRepoHistory(sysRepoHistory);
    }

    /**
     * 批量删除仓库历史版本
     * 
     * @param hIds 需要删除的仓库历史版本主键
     * @return 结果
     */
    @Override
    public int deleteSysRepoHistoryByHIds(Long[] hIds)
    {
        return sysRepoHistoryMapper.deleteSysRepoHistoryByHIds(hIds);
    }

    /**
     * 删除仓库历史版本信息
     * 
     * @param hId 仓库历史版本主键
     * @return 结果
     */
    @Override
    public int deleteSysRepoHistoryByHId(Long hId)
    {
        return sysRepoHistoryMapper.deleteSysRepoHistoryByHId(hId);
    }

    /**
     * 填充SysRepoHistory对象
     *
     * @param sysRepo 模板部分信息
     * @return 字段填充后的对象
     */
    public SysRepoHistory createSysRepoHistory(SysRepo sysRepo){
        SysRepoHistory sysRepoHistory = new SysRepoHistory();
        sysRepoHistory.setRepoId(sysRepo.getRepoId());
        sysRepoHistory.setUrl(sysRepo.getUrl());
        sysRepoHistory.setUploadBy(sysRepo.getUpdateBy());
        sysRepoHistory.setFileName(sysRepo.getFileName());
        sysRepoHistory.setVersion(sysRepo.getVersion());
        sysRepoHistory.setRemark(sysRepo.getRemark());
        return sysRepoHistory;
    }
}
