package com.ruoyi.system.service.impl;

import java.beans.Transient;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.VersionUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.system.domain.SysRepoHistory;
import com.ruoyi.system.mapper.SysRepoHistoryMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SysRepoMapper;
import com.ruoyi.system.domain.SysRepo;
import com.ruoyi.system.service.ISysRepoService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 仓库文件Service业务层处理
 * 
 * @author lixu
 * @date 2025-05-15
 */
@Service
public class SysRepoServiceImpl implements ISysRepoService 
{
    @Autowired
    private SysRepoMapper sysRepoMapper;
    @Autowired
    private SysRepoHistoryMapper sysRepoHistoryMapper;

    /**
     * 查询仓库文件
     * 
     * @param repoId 仓库文件ID
     * @return 仓库文件信息
     */
    @Override
    public SysRepo selectSysRepoByRepoId(Long repoId)
    {
        return sysRepoMapper.selectSysRepoByRepoId(repoId);
    }

    /**
     * 通过主键列表查询文件仓库信息列表
     *
     * @param repoIds 需要查询的文件仓库主键集合
     * @return 结果
     */

    public List<SysRepo> selectSysRepoListByRepoIds(Long[] repoIds){
        return sysRepoMapper.selectSysRepoListByRepoIds(repoIds);
    }
    /**
     * 查询仓库文件列表
     * 
     * @param sysRepo 仓库文件信息
     * @return 仓库文件列表
     */
    @Override
    public List<SysRepo> selectSysRepoList(SysRepo sysRepo)
    {
        return sysRepoMapper.selectSysRepoList(sysRepo);
    }

    /**
     * 新增仓库文件
     * 
     * @param sysRepo 仓库文件信息
     * @return 结果
     */
    @Override
    public int insertSysRepo(SysRepo sysRepo)
    {
        sysRepo.setCreateTime(DateUtils.getNowDate());
        return sysRepoMapper.insertSysRepo(sysRepo);
    }

    /**
     * 修改仓库文件信息
     * 
     * @param sysRepo 仓库文件信息
     * @return 结果
     */
    @Override
    public int updateSysRepo(SysRepo sysRepo)
    {
        sysRepo.setUpdateTime(DateUtils.getNowDate());
        return sysRepoMapper.updateSysRepo(sysRepo);
    }

    /**
     * 批量删除仓库文件
     * 
     * @param repoIds 需要删除的仓库文件ID集合
     * @return 结果
     */
    @Override
    public int deleteSysRepoByRepoIds(Long[] repoIds)
    {
        return sysRepoMapper.deleteSysRepoByRepoIds(repoIds);
    }

    /**
     * 删除仓库文件信息
     * 
     * @param repoId 仓库文件ID
     * @return 结果
     */
    @Override
    public int deleteSysRepoByRepoId(Long repoId)
    {
        return sysRepoMapper.deleteSysRepoByRepoId(repoId);
    }

    /**
     * 填充Sysrepo对象
     *
     * @param sysRepo 模板部分信息
     * @return 字段填充后的对象
     */
    public SysRepo createSysRepo(SysRepo sysRepo){
        String filename = FileUtils.getNameNotExtract(sysRepo.getUrl());
        sysRepo.setFileName(filename);
        sysRepo.setRepoType(FileUtils.getFileExtension(filename));
        sysRepo.setVersion(VersionUtils.incrementVersion(sysRepo.getVersion()));
        return sysRepo;
    }

    /**
     * 插入仓库文件信息
     *
     * @param sysRepo 仓库文件信息
     * @param sysRepoHistory 仓库文件历史信息
     * @return 插入结果
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public int insertSysRepoAndSysRepoHistory(SysRepo sysRepo, SysRepoHistory sysRepoHistory)
    {
       int result =sysRepoMapper.updateSysRepo(sysRepo) + sysRepoHistoryMapper.insertSysRepoHistory(sysRepoHistory);
       if(result!=2){
           throw new RuntimeException("插入失败");
       }
       return 1;
    }

}
